==> plugin.video.fenlight-1.0.84.zip: plugin.video.fenlight/resources/lib/modules/icons.py <==
# -*- coding: utf-8 -*-
alldebrid = 'UBjURaL'
anime = '52QtOjB'
audio = 'fDf9q4B'
bad_language = 'tKJVTmq'
because_you_watched = 'IFWDwai'
box_office = 'WzYp4H8'
calender = 'fN4GQmO'
calendar_decades = '2OJn9MC'
certifications = 'aHv21HF'
collections = 'SlyLIcD'
discover = 'PEdc5Bh'
downloads = 'KkNYKy6'
drugs_alcohol = 'R9alT5V'
dvd = 'b9La9Ch'
easynews = 'nkBuUe9'
edit = 'SfRFRXl'
favorites = 'uCaIeC6'
featured = 'PQkUwwA'
fenlight = 'nEUGtZP'
folder = 'I1JJhji'
fresh = 'O2bqOfI'
genres = '6QpJbS0'
github = 'wZWNeVd'
imdb = '2xNcDuj'
in_progress_tvshow = 'BfGbQXx'
information = 'ODbe89r'
intheatres = '9660DAY'
languages = 'gxgLI0J'
lists = 'XbEEv9X'
live = 'VmIhHM6'
most_watched = 'wG42SLp'
most_voted = 'aj02pjQ'
movies = 'pmyCOx7'
networks = 'pVxUSzl'
new = 's4krx5q'
next_episodes = '0KFvjKR'
nextpage = 'D2wG9Ak'
nextpage_landscape = 'YpaXaLM'
ontheair = 'Ht6HpQO'
oscar_winners = 'AMg9mQS'
people = 'jOBKuzO'
planet = 'NK71dGC'
player = 'D0nCsqI'
popular = 'ngkznpf'
popular_today = 'LKqXjQ1'
premium = 'inX030Z'
premiumize = 'nETvpPS'
providers = 'ncriWoB'
random = 'wbghfGO'
realdebrid = 'DotYAc3'
search = 'owsADQ4'
settings = 'RDNxy36'
settings2 = '4xBbqSw'
sex_nudity = 'B4NHuAp'
tmdb = 'bOqItvH'
tools = 'eofrRXT'
top = 'IOtOum6'
trakt = 'xihFNwP'
trending = 'rVq7so0'
trending_recent = 'vBwrjLV'
tv = 'R3NEEJl'
voted = '5zcHObg'
watched_1 = 'Ps93y86'
watched_recent = 'SacesHf'

rd_qrcode = 'hjZliTu'
pm_qrcode = 'ARyznQq'
ad_qrcode = 'jtIyMrl'
trakt_qrcode = 'lMrS0mS'

search_anime = 'nv2y3xo'
search_history = 'y1DEuvk'
search_imdb = 'z4C3PAx'
search_movie = 'u8jgyN3'
search_new = 'V4cjtck'
search_people = 'F1EZyWz'
search_tmdb = 'r0ITv0C'
search_tv = 'xYTdX3O'

flag_4k = 'x5FjOZy'
flag_1080p = '2ptXKKa'
flag_720p = '8ssOa9n'
flag_sd = 'kkuMi2R'

provider_easynews = '5EKdDZi'
provider_alldebrid = 'oni7Zt9'
provider_realdebrid = '7yte1nF'
provider_premiumize = 'kmNpjDb'
provider_folder = 'a508B9o'

genre_action = 'mOkM9Cs'
genre_adventure = 'SF329Ap'
genre_animation = 'xCJdDW7'
genre_anime = '52QtOjB'
genre_comedy = 'Xsb1iEl'
genre_crime = 'cE3Rovc'
genre_documentary = 'DIfwy76'
genre_drama = 'n0LmfJR'
genre_family = 'UVc9gws'
genre_fantasy = 'Y4Y3EMn'
genre_foreign = 'HUN7FxK'
genre_history = 'J5EM9MB'
genre_horror = 'SCJriF0'
genre_kids = 'cMjxdqe'
genre_music = 'Qi9NcWi'
genre_mystery = '7GCK5Tg'
genre_news = 'CjDP92M'
genre_reality = 'NZTCRcM'
genre_romance = '5OZRqUX'
genre_scifi = 'CPanVlY'
genre_soap = 'RpDSmbX'
genre_talk = 'DB5KHJf'
genre_thriller = 'ObKPLhE'
genre_war = 'MWqQbMF'
genre_western = 'MU8LKTK'

network_disney = 'ZCgEkp6'
network_disneyxd = 'PAJJoqQ'
network_abc = 'qePLxos'
network_bbcamerica = 'TUHDjfl'
network_nbc = 'yPRirQZ'
network_nickelodeon = 'OUVoqYc'
network_pbs = 'r9qeDJY'
network_cbs = '8OT8igR'
network_fox = '6vc0Iov'
network_thewb = 'rzfVME6'
network_bet = 'ZpGJ5UQ'
network_usanetwork = 'Doccw9E'
network_cbc = 'unQ7WCZ'
network_atx = 'JshJYGN'
network_mtv = 'QM6DpNW'
network_lifetime = 'tvYbhen'
network_nickjr = 'leuCWYt'
network_tnt = 'WnzpAGj'
network_natgeo = 'XCGNKVQ'
network_comedycentral = 'ko6XN77'
network_hbo = 'Hyu8ZGq'
network_spike = 'BhXYytR'
network_showtime = 'SawAYkO'
network_cartoonnetwork = 'zmOLbbI'
network_history = 'LEMgy6n'
network_tlc = 'c24MxaB'
network_tbs = 'RVCtt4Z'
network_thecw = 'Q8tooeM'
network_bravo = 'TmEO3Tn'
network_e = '3Delf9f'
network_discoveryplus = 'ukz1nOG'
network_syfy = '9yCq37i'
network_adultswim = 'jCqbRcS'
network_animalplanet = 'olKc4RP'
network_ctv = 'qUlyVHz'
network_ane = 'xLDfHjH'
network_vh1 = 'IUtHYzA'
network_amc = 'ndorJxi'
network_crackle = '53kqZSY'
network_wgnamerica = 'TL6MzgO'
network_travel = 'mWXv7SF'
network_netflix = 'jI5c3bw'
network_audience = '5Q3mo5A'
network_sundancetv = 'qldG5p2'
network_starz = 'Z0ep2Ru'
network_cinemax = 'zWypFNI'
network_trutv = 'HnB3zfc'
network_hallmark = 'zXS64I8'
network_tvland = '1nIeDA5'
network_amazon = 'ru9DDlL'
network_freeform = 'f9AqoHE'
network_bbc1 = 'u8x26te'
network_bbc2 = 'SKeGH1a'
network_bbc3 = 'SDLeLcn'
network_bbc4 = 'PNDalgw'
network_sky1 = 'xbgzhPU'
network_itv = '5Hxp5eA'
network_channel4 = '6ZA9UHR'
network_channel5 = '5ubnvOh'
network_e4 = 'frpunK8'
network_hgtv = 'INnmgLT'
network_hulu = 'uSD2Cdw'
network_youtubered = 'ZfewP1Y'
network_discovery = '8UrXnAB'
network_disneyplus = 'DVrPgbM'
network_appletvplus = 'fAQMVNp'
network_acorntv = 'fSWB5gB'
network_cbsallaccess = 'ZvaWMuU'
network_hbomax = 'mmRMG75'
network_dcuniverse = 'bhWIubn'
network_paramount = 'ez3U6NV'
network_paramountplus = 'dmUjWmU'
network_peacock = '1JXFkSM'
network_fx = 'aQc1AIZ'
network_oxygen = 'uFCQvbR'
network_discoveryid = '07w7BER'

==> plugin.video.fenlight-2.0.05.zip: plugin.video.fenlight/resources/lib/modules/icons.py <==
# -*- coding: utf-8 -*-
alldebrid = 'UBjURaL'
anime = '52QtOjB'
audio = 'fDf9q4B'
bad_language = 'tKJVTmq'
because_you_watched = 'IFWDwai'
box_office = 'WzYp4H8'
calender = 'fN4GQmO'
calendar_decades = '2OJn9MC'
certifications = 'aHv21HF'
collections = 'SlyLIcD'
discover = 'PEdc5Bh'
downloads = 'KkNYKy6'
drugs_alcohol = 'R9alT5V'
dvd = 'b9La9Ch'
easydebrid = 'Xpxoqfk'
easynews = 'nkBuUe9'
edit = 'SfRFRXl'
favorites = 'uCaIeC6'
featured = 'PQkUwwA'
fenlight = 'nEUGtZP'
folder = 'I1JJhji'
fresh = 'O2bqOfI'
genres = '6QpJbS0'
github = 'wZWNeVd'
imdb = '2xNcDuj'
in_progress_tvshow = 'BfGbQXx'
information = 'ODbe89r'
intheatres = '9660DAY'
languages = 'gxgLI0J'
lists = 'XbEEv9X'
live = 'VmIhHM6'
most_watched = 'wG42SLp'
most_voted = 'aj02pjQ'
movies = 'pmyCOx7'
networks = 'pVxUSzl'
new = 's4krx5q'
next_episodes = '0KFvjKR'
nextpage = 'D2wG9Ak'
nextpage_landscape = 'YpaXaLM'
offcloud = '4LLyOVF'
ontheair = 'Ht6HpQO'
oscar_winners = 'AMg9mQS'
people = 'jOBKuzO'
planet = 'NK71dGC'
player = 'D0nCsqI'
popular = 'ngkznpf'
popular_today = 'LKqXjQ1'
premium = 'inX030Z'
premiumize = 'nETvpPS'
providers = 'ncriWoB'
random = 'wbghfGO'
realdebrid = 'DotYAc3'
search = 'owsADQ4'
settings = 'RDNxy36'
settings2 = '4xBbqSw'
sex_nudity = 'B4NHuAp'
tmdb = 'bOqItvH'
tools = 'eofrRXT'
torbox = 'MF874vS'
top = 'IOtOum6'
trakt = 'xihFNwP'
trending = 'rVq7so0'
trending_recent = 'vBwrjLV'
tv = 'R3NEEJl'
voted = '5zcHObg'
watched_1 = 'Ps93y86'
watched_recent = 'SacesHf'

ad_qrcode = 'jtIyMrl'
pm_qrcode = 'ARyznQq'
rd_qrcode = 'hjZliTu'
trakt_qrcode = 'lMrS0mS'

search_anime = 'nv2y3xo'
search_history = 'y1DEuvk'
search_imdb = 'z4C3PAx'
search_movie = 'u8jgyN3'
search_new = 'V4cjtck'
search_people = 'F1EZyWz'
search_tmdb = 'r0ITv0C'
search_tv = 'xYTdX3O'

flag_4k = 'x5FjOZy'
flag_1080p = '2ptXKKa'
flag_720p = '8ssOa9n'
flag_sd = 'kkuMi2R'

genre_action = 'mOkM9Cs'
genre_adventure = 'SF329Ap'
genre_animation = 'xCJdDW7'
genre_anime = '52QtOjB'
genre_comedy = 'Xsb1iEl'
genre_crime = 'cE3Rovc'
genre_documentary = 'DIfwy76'
genre_drama = 'n0LmfJR'
genre_family = 'UVc9gws'
genre_fantasy = 'Y4Y3EMn'
genre_foreign = 'HUN7FxK'
genre_history = 'J5EM9MB'
genre_horror = 'SCJriF0'
genre_kids = 'cMjxdqe'
genre_music = 'Qi9NcWi'
genre_mystery = '7GCK5Tg'
genre_news = 'CjDP92M'
genre_reality = 'NZTCRcM'
genre_romance = '5OZRqUX'
genre_scifi = 'CPanVlY'
genre_soap = 'RpDSmbX'
genre_talk = 'DB5KHJf'
genre_thriller = 'ObKPLhE'
genre_war = 'MWqQbMF'
genre_western = 'MU8LKTK'

network_disney = 'ZCgEkp6'
network_disneyxd = 'PAJJoqQ'
network_abc = 'qePLxos'
network_bbcamerica = 'TUHDjfl'
network_nbc = 'yPRirQZ'
network_nickelodeon = 'OUVoqYc'
network_pbs = 'r9qeDJY'
network_cbs = '8OT8igR'
network_fox = '6vc0Iov'
network_thewb = 'rzfVME6'
network_bet = 'ZpGJ5UQ'
network_usanetwork = 'Doccw9E'
network_cbc = 'unQ7WCZ'
network_atx = 'JshJYGN'
network_mtv = 'QM6DpNW'
network_lifetime = 'tvYbhen'
network_nickjr = 'leuCWYt'
network_tnt = 'WnzpAGj'
network_natgeo = 'XCGNKVQ'
network_comedycentral = 'ko6XN77'
network_hbo = 'Hyu8ZGq'
network_spike = 'BhXYytR'
network_showtime = 'SawAYkO'
network_cartoonnetwork = 'zmOLbbI'
network_history = 'LEMgy6n'
network_tlc = 'c24MxaB'
network_tbs = 'RVCtt4Z'
network_thecw = 'Q8tooeM'
network_bravo = 'TmEO3Tn'
network_e = '3Delf9f'
network_discoveryplus = 'ukz1nOG'
network_syfy = '9yCq37i'
network_adultswim = 'jCqbRcS'
network_animalplanet = 'olKc4RP'
network_ctv = 'qUlyVHz'
network_ane = 'xLDfHjH'
network_vh1 = 'IUtHYzA'
network_amc = 'ndorJxi'
network_crackle = '53kqZSY'
network_wgnamerica = 'TL6MzgO'
network_travel = 'mWXv7SF'
network_netflix = 'jI5c3bw'
network_audience = '5Q3mo5A'
network_sundancetv = 'qldG5p2'
network_starz = 'Z0ep2Ru'
network_cinemax = 'zWypFNI'
network_trutv = 'HnB3zfc'
network_hallmark = 'zXS64I8'
network_tvland = '1nIeDA5'
network_amazon = 'ru9DDlL'
network_freeform = 'f9AqoHE'
network_bbc1 = 'u8x26te'
network_bbc2 = 'SKeGH1a'
network_bbc3 = 'SDLeLcn'
network_bbc4 = 'PNDalgw'
network_sky1 = 'xbgzhPU'
network_itv = '5Hxp5eA'
network_channel4 = '6ZA9UHR'
network_channel5 = '5ubnvOh'
network_e4 = 'frpunK8'
network_hgtv = 'INnmgLT'
network_hulu = 'uSD2Cdw'
network_youtubered = 'ZfewP1Y'
network_discovery = '8UrXnAB'
network_disneyplus = 'DVrPgbM'
network_appletvplus = 'fAQMVNp'
network_acorntv = 'fSWB5gB'
network_cbsallaccess = 'ZvaWMuU'
network_hbomax = 'mmRMG75'
network_dcuniverse = 'bhWIubn'
network_paramount = 'ez3U6NV'
network_paramountplus = 'dmUjWmU'
network_peacock = '1JXFkSM'
network_fx = 'aQc1AIZ'
network_oxygen = 'uFCQvbR'
network_discoveryid = '07w7BER'
